@@ -15,7 +15,7 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
     Widget showing a video thumbnail, duration, title, 
     author and rating.
     """
-    def __init__(self, video, parent = None):
+    def __init__(self, parent, video):
         """
         Constructor
         """
@@ -27,11 +27,7 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
             self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
         except:
             self.durationLabel.setText("--")
-        self.authorLabel.setText(unicode(video.author[0].name.text, "utf-8"))
-        try:
-            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating%s.png" % unicode(round(float(video.rating.average)))))
-        except:
-            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating3.0.png"))  
+        self.authorLabel.setText("By %s on %s" % (unicode(video.media.credit.text, "utf-8"), video.media.uploaded.text.split("T")[0]))
             
     def ignoreClick(self, event):
         """
@@ -44,8 +40,8 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
         Hides the widget's checkbox.
         """       
         self.thumbLabel.move(0, 2)
-        self.durationLabel.move(53, 53)
-        self.widget.setGeometry(QRect(110, 0, 690, 79))
+        self.durationLabel.move(73, 68)
+        self.widget.setGeometry(QRect(130, 0, 670, 94))
         self.checkBox.setVisible(False)
         self.checkBox.setCheckState(Qt.Unchecked)
 
@@ -54,8 +50,8 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
         Displays the widget's checkbox.
         """
         self.thumbLabel.move(70, 2)
-        self.durationLabel.move(123, 53)
-        self.widget.setGeometry(QRect(180, 0, 620, 79))
+        self.durationLabel.move(143, 68)
+        self.widget.setGeometry(QRect(200, 0, 590, 94))
         self.checkBox.setVisible(True)
 
 
@@ -75,7 +71,7 @@ class VideoDownloadItemWidget(QWidget, Ui_VideoDownloadWidget):
     with an additional progress bar showing the download 
     progress.
     """
-    def __init__(self, video, parent = None):
+    def __init__(self, parent, video):
         """
         Constructor
         """
@@ -92,17 +88,17 @@ class VideoDownloadItemWidget(QWidget, Ui_VideoDownloadWidget):
         """
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.widget.setGeometry(QRect(110, 2, 210, 75))
-            self.progressBar.setGeometry(QRect(330, 2, 120, 75))
+            self.widget.setGeometry(QRect(130, 2, 180, 90))
+            self.progressBar.setGeometry(QRect(330, 2, 120, 90))
         else:
-            self.widget.setGeometry(QRect(110, 2, 500, 75))
-            self.progressBar.setGeometry(QRect(620, 2, 150, 75))
+            self.widget.setGeometry(QRect(130, 2, 470, 90))
+            self.progressBar.setGeometry(QRect(620, 2, 150, 90))
 
 class CommentWidget(QWidget):
     """
     Widget displaying comment author and comment text.
     """
-    def __init__(self, author, comment, parent = None):
+    def __init__(self, parent, author, comment):
         """
         Constructor
         """
@@ -122,12 +118,3 @@ class CommentWidget(QWidget):
         self.vbox.addWidget(self.textEdit)
         self.setLayout(self.vbox)
         self.show()
-
-class PlaylistWidget(QWidget):
-    def __init__(self, title, parent = None):
-        QWidget.__init__(self, parent)
-        self.setMininumSize(800, 50)
-        self.titleLabel = QLabel(unicode(title, "utf-8"))
-        self.titleLabel.setGeometry(QRect(0, 0, 800, 50))
-        self.titleLabel.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
-        self.show()
