@@ -51,6 +51,7 @@ class YouTubeDataService(object):
             YouTubeDataService.ytService.ProgrammaticLogin()
             YouTubeDataService.currentUser = username
             CutetubeLog.logInfo("Signed in to YouTube account: %s" % username)
+            result = True
         except:
             try:
                 # Some users have reported authentication issues. Using the username in place of the email address may work.
@@ -59,8 +60,11 @@ class YouTubeDataService(object):
                 YouTubeDataService.ytService.ProgrammaticLogin()
                 YouTubeDataService.currentUser = username
                 CutetubeLog.logInfo("Signed in to YouTube account: %s" % username)
+                result = True
             except Exception, e:
                 CutetubeLog.logException("Unable to sign in to YouTube account:")
+                result = False
+        return result
         
     @staticmethod
     def addComment(comment, videoId):
@@ -288,7 +292,6 @@ class YouTubeVideoFeed(QThread):
         self.videoList = []
         self.results = 0
         self.thumbcount = 0
-        self.retriesRemaining = 3
         self.moreResults = True
         
     def resetResultCount(self):
@@ -299,7 +302,7 @@ class YouTubeVideoFeed(QThread):
         self.results = 0
         self.thumbcount = 0
     
-    def getVideoFeed(self):
+    def getVideoFeed(self, retriesRemaining = 3):
         """
         Retrieves and returns the video feed.
         """
@@ -311,10 +314,10 @@ class YouTubeVideoFeed(QThread):
             for link in self.ytVideoFeed.link:
                 self.moreResults = (link.rel == "next")
         except Exception, e:
-            if self.retriesRemaining > 0:
+            if retriesRemaining > 0:
+                retriesRemaining -= 1                
                 CutetubeLog.logException("Unable to retrieve video feed. Trying again")
-                self.retriesRemaining -= 1
-                self.getVideoFeed()
+                self.getVideoFeed(retriesRemaining)
             else:
                 CutetubeLog.logException("Unable to retrieve video feed. Aborting")
             
@@ -345,12 +348,10 @@ class YouTubeVideoFeed(QThread):
 
     def run(self):
         self.emit(SIGNAL("feedCompleted(bool)"), True)
-        if self.results == 0:
-            self.getVideoFeed() 
+        self.getVideoFeed() 
         self.getVideoData()
         self.emit(SIGNAL("feedCompleted(bool)"), False)
         self.getThumbnails()
-        self.getVideoFeed()
 
 class YouTubeQueueFeed(QThread):
     """
@@ -603,7 +604,7 @@ class YouTubeVideoDownloader(object):
         for task in YouTubeVideoDownloader.taskQueue:
             if task.getStatus() == "queued":
                 YouTubeVideoDownloader.currentTask = task
-                YouTubeVideoDownloader.currentTask.start()
+                YouTubeVideoDownloader.currentTask.start(QThread.LowPriority)
                 YouTubeVideoDownloader.currentStatus = "active"
                 break
         else:
